==> hyades.source_1.1.0_20030930_2244.zip: org/eclipse/hyades/test/common/event/MessageEvent.java <==
/**********************************************************************
 * Copyright (c) 2003 Hyades project.
 * All rights reserved.   This program and the accompanying materials
 * are made available under the terms of the Common Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/cpl-v10.html
 * 
 * Contributors: 
 * IBM - Initial API and implementation
 **********************************************************************/
package org.eclipse.hyades.test.common.event;

import org.eclipse.hyades.test.common.util.XMLUtil;


/**
 * This is a flat class packaged in the execution environment and
 * it mirrors the 
 * {@link org.eclipse.hyades.models.common.testprofile.TPFMessageEvent}.
 * 
 * @author kobylin
 * @author marcelop
 */
public class MessageEvent 
extends ExecutionEvent
{
	public static final int INFO = 0;
	public static final int ERROR = 1;
	public static final int WARNING = 2;

	private int severity = NOT_INITIALIZED_VALUE;

	/**
	 * Sets the severity of this event.
	 * @param value
	 */
	public void setSeverity(int value)
	{
		severity = value;
	}

	/**
	 * Returns the severity of this event.
	 * @return int
	 */
	public int getSeverity()
	{
		return severity;
	}
	
	/**
	 * @see org.eclipse.hyades.test.java.event.ExecutionEvent#getXMLRoot()
	 */
	protected String getXMLRoot()
	{
		return "messageEvent";
	}

	/**
	 * @see org.eclipse.hyades.test.java.event.ExecutionEvent#addXMLAttributes(java.lang.StringBuffer)
	 */
	protected void addXMLAttributes(StringBuffer xml)
	{
		super.addXMLAttributes(xml);
		
		if(getSeverity() != NOT_INITIALIZED_VALUE)
			xml.append(XMLUtil.createXMLAttribute("severity", Integer.toString(getSeverity()), false));
	}	
}

==> hyades.source_3.0.2_20050225_1641.zip: org/eclipse/hyades/test/common/event/MessageEvent.java <==
/**********************************************************************
 * Copyright (c) 2003 Hyades project.
 * All rights reserved.   This program and the accompanying materials
 * are made available under the terms of the Common Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/cpl-v10.html
 * 
 * Contributors: 
 * IBM - Initial API and implementation
 **********************************************************************/
package org.eclipse.hyades.test.common.event;

import org.eclipse.hyades.test.common.util.XMLUtil;


/**
 * This is a flat class packaged in the execution environment and
 * it mirrors the 
 * {@link org.eclipse.hyades.models.common.testprofile.TPFMessageEvent}.
 * 
 * @author kobylin
 * @author marcelop
 */
public class MessageEvent 
extends ExecutionEvent
{
	public static final int INFO = 0;
	public static final int ERROR = 1;
	public static final int WARNING = 2;

	private int severity = NOT_INITIALIZED_VALUE;

	/**
	 * Sets the severity of this event.
	 * @param value
	 */
	public void setSeverity(int value)
	{
		severity = value;
	}

	/**
	 * Returns the severity of this event.
	 * @return int
	 */
	public int getSeverity()
	{
		return severity;
	}
	
	/**
	 * @see org.eclipse.hyades.test.java.event.ExecutionEvent#getXMLRoot()
	 */
	protected String getXMLRoot()
	{
		return "messageEvent";
	}

	/**
	 * @see org.eclipse.hyades.test.java.event.ExecutionEvent#addXMLAttributes(java.lang.StringBuffer)
	 */
	protected void addXMLAttributes(StringBuffer xml)
	{
		super.addXMLAttributes(xml);
		
		if(getSeverity() != NOT_INITIALIZED_VALUE)
			xml.append((XMLUtil.createXMLAttribute("severity", Integer.toString(getSeverity()), false)).toString());
	}	
}
